CVideoConfig

Struct CVideoConfig 

pub struct CVideoConfig<'t, NF>
where NF: NoFields,
{ /* private fields */ }

Implementations

Source

impl<'t, NF> CVideoConfig<'t, NF>
where NF: NoFields,

pub const fn check(&self) -> bool

Some basic checks on the provided values.

pub const fn display_columns(&self) -> u32

The amount of display columns, i.e. the width in number of pixels

pub const fn cpu_ticks_per_field(&self) -> u32

The number of CPU clock cycles per field

In case of progressive video, this is the duration for one frame. In case of interlaced, this indicates the exact mean duration of the two fields.

pub const fn display_lines(&self) -> u32

Pixel height

In case of interlaced, includes both the odd and even lines

pub const fn needed_buffer_size(&self) -> usize

Number of u32 words needed for this configuration

Includes optional double buffering. Function is const so this can be used to allocate static buffers

Source

impl CVideoConfig<'static, OneField>

pub const fn from_constraints_semi_double_buffered( horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, OneField>, &'static str>

pub const fn from_constraints_progressive( buffering_mode: BufferingMode, horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, OneField>, &'static str>

Source

impl CVideoConfig<'static, TwoFields>

pub const fn from_constraints_interlaced( buffering_mode: BufferingMode, horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, TwoFields>, &'static str>