pub struct CVideoConfig<'t, NF>where
NF: NoFields,{ /* private fields */ }Implementations
Sourceimpl<'t, NF> CVideoConfig<'t, NF>where
NF: NoFields,
impl<'t, NF> CVideoConfig<'t, NF>where
NF: NoFields,
Sourcepub const fn display_columns(&self) -> u32
pub const fn display_columns(&self) -> u32
The amount of display columns, i.e. the width in number of pixels
Sourcepub const fn cpu_ticks_per_field(&self) -> u32
pub const fn cpu_ticks_per_field(&self) -> u32
The number of CPU clock cycles per field
In case of progressive video, this is the duration for one frame. In case of interlaced, this indicates the exact mean duration of the two fields.
Sourcepub const fn display_lines(&self) -> u32
pub const fn display_lines(&self) -> u32
Pixel height
In case of interlaced, includes both the odd and even lines
Sourcepub const fn needed_buffer_size(&self) -> usize
pub const fn needed_buffer_size(&self) -> usize
Number of u32 words needed for this configuration
Includes optional double buffering. Function is const so this can be used to allocate static buffers
Sourceimpl CVideoConfig<'static, OneField>
impl CVideoConfig<'static, OneField>
pub const fn from_constraints_semi_double_buffered( horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, OneField>, &'static str>
pub const fn from_constraints_progressive( buffering_mode: BufferingMode, horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, OneField>, &'static str>
Sourceimpl CVideoConfig<'static, TwoFields>
impl CVideoConfig<'static, TwoFields>
pub const fn from_constraints_interlaced( buffering_mode: BufferingMode, horizontal: HorizontalConstraint, vertical: VerticalConstraint, standard_durations: StandardDurations, pio_freq: u64, ) -> Result<CVideoConfig<'static, TwoFields>, &'static str>