pub struct DisplayBuffer<'t, FieldCount>where
FieldCount: NoFields,{
pub columns: u32,
pub lines: u32,
/* private fields */
}Expand description
DisplayBuffer
Contains either one or two fields. In case of progressive video, a field is just the same as the whole frame. In case of interlaced, it’s the image from either the odd or even lines.
Fields
columns: u32The number of pixels horizontally
lines: u32The number of pixels vertically